# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: auth/v2/auth_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "auth/v2/auth_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1a\x61uth/v2/auth_service.proto\x12\x07\x61uth.v2\x1a\x13\x61uth/v2/token.proto\x1a\x16\x63ommon/v2/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x12user/v2/user.proto"@\n\x0cLoginRequest\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password"\x8e\x01\n\rLoginResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12(\n\x05token\x18\x02 \x01(\x0b\x32\x12.auth.v2.AuthTokenR\x05token\x12(\n\x04user\x18\x03 \x01(\x0b\x32\x14.user.v2.UserProfileR\x04user":\n\x13RefreshTokenRequest\x12#\n\rrefresh_token\x18\x01 \x01(\tR\x0crefreshToken"k\n\x14RefreshTokenResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12(\n\x05token\x18\x02 \x01(\x0b\x32\x12.auth.v2.AuthTokenR\x05token";\n\x0eLogoutResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status2\xd3\x01\n\x0b\x41uthService\x12\x38\n\x05Login\x12\x15.auth.v2.LoginRequest\x1a\x16.auth.v2.LoginResponse"\x00\x12M\n\x0cRefreshToken\x12\x1c.auth.v2.RefreshTokenRequest\x1a\x1d.auth.v2.RefreshTokenResponse"\x00\x12;\n\x06Logout\x12\x16.google.protobuf.Empty\x1a\x17.auth.v2.LogoutResponse"\x00\x42\x98\x01\n\x0b\x63om.auth.v2B\x10\x41uthServiceProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\xa2\x02\x03\x41XX\xaa\x02\x07\x41uth.V2\xca\x02\x07\x41uth\\V2\xe2\x02\x13\x41uth\\V2\\GPBMetadata\xea\x02\x08\x41uth::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "auth.v2.auth_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\013com.auth.v2B\020AuthServiceProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/auth/v2;authv2\242\002\003AXX\252\002\007Auth.V2\312\002\007Auth\\V2\342\002\023Auth\\V2\\GPBMetadata\352\002\010Auth::V2"
    _globals["_LOGINREQUEST"]._serialized_start = 133
    _globals["_LOGINREQUEST"]._serialized_end = 197
    _globals["_LOGINRESPONSE"]._serialized_start = 200
    _globals["_LOGINRESPONSE"]._serialized_end = 342
    _globals["_REFRESHTOKENREQUEST"]._serialized_start = 344
    _globals["_REFRESHTOKENREQUEST"]._serialized_end = 402
    _globals["_REFRESHTOKENRESPONSE"]._serialized_start = 404
    _globals["_REFRESHTOKENRESPONSE"]._serialized_end = 511
    _globals["_LOGOUTRESPONSE"]._serialized_start = 513
    _globals["_LOGOUTRESPONSE"]._serialized_end = 572
    _globals["_AUTHSERVICE"]._serialized_start = 575
    _globals["_AUTHSERVICE"]._serialized_end = 786
# @@protoc_insertion_point(module_scope)
