# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/stream_operations.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/stream_operations.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from spounge.polykey.v2 import common_pb2 as polykey_dot_v2_dot_common__pb2
from spounge.polykey.v2 import single_operations_pb2 as polykey_dot_v2_dot_single__operations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"polykey/v2/stream_operations.proto\x12\npolykey.v2\x1a\x17polykey/v2/common.proto\x1a\"polykey/v2/single_operations.proto\"\x8c\x02\n\x14StreamGetKeysRequest\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12I\n\x11requester_context\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x03 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\x12(\n\rskip_metadata\x18\x05 \x01(\x08H\x00R\x0cskipMetadata\x88\x01\x01\x42\x10\n\x0e_skip_metadata\"Q\n\x17StreamCreateKeysRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.CreateKeyRequestR\x07request\"Q\n\x17StreamRotateKeysRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RotateKeyRequestR\x07request\"Q\n\x17StreamRevokeKeysRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RevokeKeyRequestR\x07request\"`\n\x1eStreamUpdateKeyMetadataRequest\x12>\n\x07request\x18\x01 \x01(\x0b\x32$.polykey.v2.UpdateKeyMetadataRequestR\x07request\"Z\n\x1bStreamGetKeyMetadataRequest\x12;\n\x07request\x18\x01 \x01(\x0b\x32!.polykey.v2.GetKeyMetadataRequestR\x07request\"\xb1\x01\n\x15StreamGetKeysResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x36\n\x07success\x18\x02 \x01(\x0b\x32\x1a.polykey.v2.GetKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rror\x12\'\n\x0fsequence_number\x18\x04 \x01(\x05R\x0esequenceNumberB\x08\n\x06result\"\xa2\x01\n\x18StreamCreateKeysResponse\x12)\n\x10request_sequence\x18\x01 \x01(\x05R\x0frequestSequence\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.CreateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\x8e\x01\n\x18StreamRotateKeysResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.RotateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"o\n\x18StreamRevokeKeysResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"v\n\x1fStreamUpdateKeyMetadataResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\x97\x01\n\x1cStreamGetKeyMetadataResponse\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12>\n\x07success\x18\x02 \x01(\x0b\x32\".polykey.v2.GetKeyMetadataResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06resultB\xb1\x01\n\x0e\x63om.polykey.v2B\x15StreamOperationsProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.stream_operations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\025StreamOperationsProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_STREAMGETKEYSREQUEST']._serialized_start=112
  _globals['_STREAMGETKEYSREQUEST']._serialized_end=380
  _globals['_STREAMCREATEKEYSREQUEST']._serialized_start=382
  _globals['_STREAMCREATEKEYSREQUEST']._serialized_end=463
  _globals['_STREAMROTATEKEYSREQUEST']._serialized_start=465
  _globals['_STREAMROTATEKEYSREQUEST']._serialized_end=546
  _globals['_STREAMREVOKEKEYSREQUEST']._serialized_start=548
  _globals['_STREAMREVOKEKEYSREQUEST']._serialized_end=629
  _globals['_STREAMUPDATEKEYMETADATAREQUEST']._serialized_start=631
  _globals['_STREAMUPDATEKEYMETADATAREQUEST']._serialized_end=727
  _globals['_STREAMGETKEYMETADATAREQUEST']._serialized_start=729
  _globals['_STREAMGETKEYMETADATAREQUEST']._serialized_end=819
  _globals['_STREAMGETKEYSRESPONSE']._serialized_start=822
  _globals['_STREAMGETKEYSRESPONSE']._serialized_end=999
  _globals['_STREAMCREATEKEYSRESPONSE']._serialized_start=1002
  _globals['_STREAMCREATEKEYSRESPONSE']._serialized_end=1164
  _globals['_STREAMROTATEKEYSRESPONSE']._serialized_start=1167
  _globals['_STREAMROTATEKEYSRESPONSE']._serialized_end=1309
  _globals['_STREAMREVOKEKEYSRESPONSE']._serialized_start=1311
  _globals['_STREAMREVOKEKEYSRESPONSE']._serialized_end=1422
  _globals['_STREAMUPDATEKEYMETADATARESPONSE']._serialized_start=1424
  _globals['_STREAMUPDATEKEYMETADATARESPONSE']._serialized_end=1542
  _globals['_STREAMGETKEYMETADATARESPONSE']._serialized_start=1545
  _globals['_STREAMGETKEYMETADATARESPONSE']._serialized_end=1696
# @@protoc_insertion_point(module_scope)
