# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: api/v2/workflow_gateway_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    "",
    "api/v2/workflow_gateway_service.proto",
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%api/v2/workflow_gateway_service.proto\x12\x06\x61pi.v2\x1a\x1cgoogle/api/annotations.proto\x1a#workflow/v2/execution_service.proto\x1a"workflow/v2/workflow_service.proto"\x89\x01\n+WorkflowGatewayServiceCreateWorkflowRequest\x12Z\n\x17\x63reate_workflow_request\x18\x01 \x01(\x0b\x32".workflow.v2.CreateWorkflowRequestR\x15\x63reateWorkflowRequest"\x8d\x01\n,WorkflowGatewayServiceCreateWorkflowResponse\x12]\n\x18\x63reate_workflow_response\x18\x01 \x01(\x0b\x32#.workflow.v2.CreateWorkflowResponseR\x16\x63reateWorkflowResponse"}\n(WorkflowGatewayServiceGetWorkflowRequest\x12Q\n\x14get_workflow_request\x18\x01 \x01(\x0b\x32\x1f.workflow.v2.GetWorkflowRequestR\x12getWorkflowRequest"\x81\x01\n)WorkflowGatewayServiceGetWorkflowResponse\x12T\n\x15get_workflow_response\x18\x01 \x01(\x0b\x32 .workflow.v2.GetWorkflowResponseR\x13getWorkflowResponse"\x85\x01\n*WorkflowGatewayServiceListWorkflowsRequest\x12W\n\x16list_workflows_request\x18\x01 \x01(\x0b\x32!.workflow.v2.ListWorkflowsRequestR\x14listWorkflowsRequest"\x89\x01\n+WorkflowGatewayServiceListWorkflowsResponse\x12Z\n\x17list_workflows_response\x18\x01 \x01(\x0b\x32".workflow.v2.ListWorkflowsResponseR\x15listWorkflowsResponse"\x89\x01\n+WorkflowGatewayServiceStartExecutionRequest\x12Z\n\x17start_execution_request\x18\x01 \x01(\x0b\x32".workflow.v2.StartExecutionRequestR\x15startExecutionRequest"\x8d\x01\n,WorkflowGatewayServiceStartExecutionResponse\x12]\n\x18start_execution_response\x18\x01 \x01(\x0b\x32#.workflow.v2.StartExecutionResponseR\x16startExecutionResponse"\x81\x01\n)WorkflowGatewayServiceGetExecutionRequest\x12T\n\x15get_execution_request\x18\x01 \x01(\x0b\x32 .workflow.v2.GetExecutionRequestR\x13getExecutionRequest"\x85\x01\n*WorkflowGatewayServiceGetExecutionResponse\x12W\n\x16get_execution_response\x18\x01 \x01(\x0b\x32!.workflow.v2.GetExecutionResponseR\x14getExecutionResponse2\xec\x06\n\x16WorkflowGatewayService\x12\x95\x01\n\x0e\x43reateWorkflow\x12\x33.api.v2.WorkflowGatewayServiceCreateWorkflowRequest\x1a\x34.api.v2.WorkflowGatewayServiceCreateWorkflowResponse"\x18\x82\xd3\xe4\x93\x02\x12"\r/v2/workflows:\x01*\x12\xac\x01\n\x0bGetWorkflow\x12\x30.api.v2.WorkflowGatewayServiceGetWorkflowRequest\x1a\x31.api.v2.WorkflowGatewayServiceGetWorkflowResponse"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v2/workflows/{get_workflow_request.workflow_id}\x12\x8f\x01\n\rListWorkflows\x12\x32.api.v2.WorkflowGatewayServiceListWorkflowsRequest\x1a\x33.api.v2.WorkflowGatewayServiceListWorkflowsResponse"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v2/workflows\x12\xc3\x01\n\x0eStartExecution\x12\x33.api.v2.WorkflowGatewayServiceStartExecutionRequest\x1a\x34.api.v2.WorkflowGatewayServiceStartExecutionResponse"F\x82\xd3\xe4\x93\x02@";/v2/workflows/{start_execution_request.workflow_id}/execute:\x01*\x12\xb2\x01\n\x0cGetExecution\x12\x31.api.v2.WorkflowGatewayServiceGetExecutionRequest\x1a\x32.api.v2.WorkflowGatewayServiceGetExecutionResponse";\x82\xd3\xe4\x93\x02\x35\x12\x33/v2/executions/{get_execution_request.execution_id}B\x9c\x01\n\ncom.api.v2B\x1bWorkflowGatewayServiceProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\xa2\x02\x03\x41XX\xaa\x02\x06\x41pi.V2\xca\x02\x06\x41pi\\V2\xe2\x02\x12\x41pi\\V2\\GPBMetadata\xea\x02\x07\x41pi::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "api.v2.workflow_gateway_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\ncom.api.v2B\033WorkflowGatewayServiceProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/api/v2;apiv2\242\002\003AXX\252\002\006Api.V2\312\002\006Api\\V2\342\002\022Api\\V2\\GPBMetadata\352\002\007Api::V2"
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "CreateWorkflow"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "CreateWorkflow"
    ]._serialized_options = b'\202\323\344\223\002\022"\r/v2/workflows:\001*'
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetWorkflow"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetWorkflow"
    ]._serialized_options = (
        b"\202\323\344\223\0022\0220/v2/workflows/{get_workflow_request.workflow_id}"
    )
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "ListWorkflows"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "ListWorkflows"
    ]._serialized_options = b"\202\323\344\223\002\017\022\r/v2/workflows"
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "StartExecution"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "StartExecution"
    ]._serialized_options = b'\202\323\344\223\002@";/v2/workflows/{start_execution_request.workflow_id}/execute:\001*'
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetExecution"
    ]._loaded_options = None
    _globals["_WORKFLOWGATEWAYSERVICE"].methods_by_name[
        "GetExecution"
    ]._serialized_options = (
        b"\202\323\344\223\0025\0223/v2/executions/{get_execution_request.execution_id}"
    )
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWREQUEST"]._serialized_start = 153
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWREQUEST"]._serialized_end = 290
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWRESPONSE"]._serialized_start = 293
    _globals["_WORKFLOWGATEWAYSERVICECREATEWORKFLOWRESPONSE"]._serialized_end = 434
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWREQUEST"]._serialized_start = 436
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWREQUEST"]._serialized_end = 561
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWRESPONSE"]._serialized_start = 564
    _globals["_WORKFLOWGATEWAYSERVICEGETWORKFLOWRESPONSE"]._serialized_end = 693
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSREQUEST"]._serialized_start = 696
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSREQUEST"]._serialized_end = 829
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSRESPONSE"]._serialized_start = 832
    _globals["_WORKFLOWGATEWAYSERVICELISTWORKFLOWSRESPONSE"]._serialized_end = 969
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONREQUEST"]._serialized_start = 972
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONREQUEST"]._serialized_end = 1109
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONRESPONSE"]._serialized_start = 1112
    _globals["_WORKFLOWGATEWAYSERVICESTARTEXECUTIONRESPONSE"]._serialized_end = 1253
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONREQUEST"]._serialized_start = 1256
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONREQUEST"]._serialized_end = 1385
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONRESPONSE"]._serialized_start = 1388
    _globals["_WORKFLOWGATEWAYSERVICEGETEXECUTIONRESPONSE"]._serialized_end = 1521
    _globals["_WORKFLOWGATEWAYSERVICE"]._serialized_start = 1524
    _globals["_WORKFLOWGATEWAYSERVICE"]._serialized_end = 2400
# @@protoc_insertion_point(module_scope)
