# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: workflow/v2/execution_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "workflow/v2/execution_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#workflow/v2/execution_service.proto\x12\x0bworkflow.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bworkflow/v2/execution.proto"\xbf\x01\n\x15StartExecutionRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12.\n\x10workflow_version\x18\x02 \x01(\x05H\x00R\x0fworkflowVersion\x88\x01\x01\x12@\n\x0finitial_context\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x0einitialContextB\x13\n\x11_workflow_version"V\n\x16StartExecutionResponse\x12<\n\texecution\x18\x01 \x01(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\texecution"8\n\x13GetExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId"T\n\x14GetExecutionResponse\x12<\n\texecution\x18\x01 \x01(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\texecution"u\n\x15ListExecutionsRequest\x12\x1f\n\x0bworkflow_id\x18\x01 \x01(\tR\nworkflowId\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationParamsR\npagination"\x95\x01\n\x16ListExecutionsResponse\x12>\n\nexecutions\x18\x01 \x03(\x0b\x32\x1e.workflow.v2.WorkflowExecutionR\nexecutions\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.common.v2.PaginationResultR\npagination";\n\x16\x43\x61ncelExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId"D\n\x17\x43\x61ncelExecutionResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status";\n\x16StreamExecutionRequest\x12!\n\x0c\x65xecution_id\x18\x01 \x01(\tR\x0b\x65xecutionId"W\n\x17StreamExecutionResponse\x12<\n\x06update\x18\x01 \x01(\x0b\x32$.workflow.v2.WorkflowExecutionUpdateR\x06update2\xe5\x03\n\x10\x45xecutionService\x12[\n\x0eStartExecution\x12".workflow.v2.StartExecutionRequest\x1a#.workflow.v2.StartExecutionResponse"\x00\x12U\n\x0cGetExecution\x12 .workflow.v2.GetExecutionRequest\x1a!.workflow.v2.GetExecutionResponse"\x00\x12[\n\x0eListExecutions\x12".workflow.v2.ListExecutionsRequest\x1a#.workflow.v2.ListExecutionsResponse"\x00\x12^\n\x0f\x43\x61ncelExecution\x12#.workflow.v2.CancelExecutionRequest\x1a$.workflow.v2.CancelExecutionResponse"\x00\x12`\n\x0fStreamExecution\x12#.workflow.v2.StreamExecutionRequest\x1a$.workflow.v2.StreamExecutionResponse"\x00\x30\x01\x42\xb9\x01\n\x0f\x63om.workflow.v2B\x15\x45xecutionServiceProtoP\x01ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\xa2\x02\x03WXX\xaa\x02\x0bWorkflow.V2\xca\x02\x0bWorkflow\\V2\xe2\x02\x17Workflow\\V2\\GPBMetadata\xea\x02\x0cWorkflow::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "workflow.v2.execution_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\017com.workflow.v2B\025ExecutionServiceProtoP\001ZBgithub.com/spounge-ai/spounge-protos/gen/go/workflow/v2;workflowv2\242\002\003WXX\252\002\013Workflow.V2\312\002\013Workflow\\V2\342\002\027Workflow\\V2\\GPBMetadata\352\002\014Workflow::V2"
    _globals["_STARTEXECUTIONREQUEST"]._serialized_start = 136
    _globals["_STARTEXECUTIONREQUEST"]._serialized_end = 327
    _globals["_STARTEXECUTIONRESPONSE"]._serialized_start = 329
    _globals["_STARTEXECUTIONRESPONSE"]._serialized_end = 415
    _globals["_GETEXECUTIONREQUEST"]._serialized_start = 417
    _globals["_GETEXECUTIONREQUEST"]._serialized_end = 473
    _globals["_GETEXECUTIONRESPONSE"]._serialized_start = 475
    _globals["_GETEXECUTIONRESPONSE"]._serialized_end = 559
    _globals["_LISTEXECUTIONSREQUEST"]._serialized_start = 561
    _globals["_LISTEXECUTIONSREQUEST"]._serialized_end = 678
    _globals["_LISTEXECUTIONSRESPONSE"]._serialized_start = 681
    _globals["_LISTEXECUTIONSRESPONSE"]._serialized_end = 830
    _globals["_CANCELEXECUTIONREQUEST"]._serialized_start = 832
    _globals["_CANCELEXECUTIONREQUEST"]._serialized_end = 891
    _globals["_CANCELEXECUTIONRESPONSE"]._serialized_start = 893
    _globals["_CANCELEXECUTIONRESPONSE"]._serialized_end = 961
    _globals["_STREAMEXECUTIONREQUEST"]._serialized_start = 963
    _globals["_STREAMEXECUTIONREQUEST"]._serialized_end = 1022
    _globals["_STREAMEXECUTIONRESPONSE"]._serialized_start = 1024
    _globals["_STREAMEXECUTIONRESPONSE"]._serialized_end = 1111
    _globals["_EXECUTIONSERVICE"]._serialized_start = 1114
    _globals["_EXECUTIONSERVICE"]._serialized_end = 1599
# @@protoc_insertion_point(module_scope)
