# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from api.v2 import (
    user_gateway_service_pb2 as api_dot_v2_dot_user__gateway__service__pb2,
)


class UserGatewayServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserProfile = channel.unary_unary(
            "/api.v2.UserGatewayService/GetUserProfile",
            request_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.FromString,
            _registered_method=True,
        )
        self.UpdateUserProfile = channel.unary_unary(
            "/api.v2.UserGatewayService/UpdateUserProfile",
            request_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.SerializeToString,
            response_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.FromString,
            _registered_method=True,
        )


class UserGatewayServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UserGatewayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserProfile,
            request_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.FromString,
            response_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.SerializeToString,
        ),
        "UpdateUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUserProfile,
            request_deserializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.FromString,
            response_serializer=api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "api.v2.UserGatewayService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "api.v2.UserGatewayService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class UserGatewayService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.UserGatewayService/GetUserProfile",
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileRequest.SerializeToString,
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceGetUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def UpdateUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/api.v2.UserGatewayService/UpdateUserProfile",
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileRequest.SerializeToString,
            api_dot_v2_dot_user__gateway__service__pb2.UserGatewayServiceUpdateUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
