# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/batch_operations.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/batch_operations.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.polykey.v2 import common_pb2 as polykey_dot_v2_dot_common__pb2
from spounge.polykey.v2 import key_types_pb2 as polykey_dot_v2_dot_key__types__pb2
from spounge.polykey.v2 import single_operations_pb2 as polykey_dot_v2_dot_single__operations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!polykey/v2/batch_operations.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17polykey/v2/common.proto\x1a\x1apolykey/v2/key_types.proto\x1a\"polykey/v2/single_operations.proto\"f\n\x0eKeyRequestItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x18\n\x07version\x18\x02 \x01(\x05R\x07version\x12#\n\rskip_metadata\x18\x03 \x01(\x08R\x0cskipMetadata\"\xfa\x01\n\x13\x42\x61tchGetKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12.\n\x04keys\x18\x03 \x03(\x0b\x32\x1a.polykey.v2.KeyRequestItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x04 \x01(\x08R\x0f\x63ontinueOnError\"\x85\x01\n\x12\x42\x61tchGetKeysResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x36\n\x07success\x18\x02 \x01(\x0b\x32\x1a.polykey.v2.GetKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xe9\x01\n\x14\x42\x61tchGetKeysResponse\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\x1e.polykey.v2.BatchGetKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xbd\x05\n\rCreateKeyItem\x12.\n\x08key_type\x18\x01 \x01(\x0e\x32\x13.polykey.v2.KeyTypeR\x07keyType\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x37\n\x04tags\x18\x03 \x03(\x0b\x32#.polykey.v2.CreateKeyItem.TagsEntryR\x04tags\x12\x39\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x12>\n\x1binitial_authorized_contexts\x18\x05 \x03(\tR\x19initialAuthorizedContexts\x12V\n\x0f\x61\x63\x63\x65ss_policies\x18\x06 \x03(\x0b\x32-.polykey.v2.CreateKeyItem.AccessPoliciesEntryR\x0e\x61\x63\x63\x65ssPolicies\x12/\n\x13\x64\x61ta_classification\x18\x07 \x01(\tR\x12\x64\x61taClassification\x12\\\n\x11generation_params\x18\x08 \x03(\x0b\x32/.polykey.v2.CreateKeyItem.GenerationParamsEntryR\x10generationParams\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x41\n\x13\x41\x63\x63\x65ssPoliciesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd6\x01\n\x16\x42\x61tchCreateKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12-\n\x04keys\x18\x02 \x03(\x0b\x32\x19.polykey.v2.CreateKeyItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"\x99\x01\n\x15\x42\x61tchCreateKeysResult\x12#\n\rrequest_index\x18\x01 \x01(\x05R\x0crequestIndex\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.CreateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xef\x01\n\x17\x42\x61tchCreateKeysResponse\x12;\n\x07results\x18\x01 \x03(\x0b\x32!.polykey.v2.BatchCreateKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xef\x02\n\rRotateKeyItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x38\n\x08strategy\x18\x02 \x01(\x0e\x32\x1c.polykey.v2.RotationStrategyR\x08strategy\x12\x30\n\x14grace_period_seconds\x18\x03 \x01(\x05R\x12gracePeriodSeconds\x12\\\n\x11generation_params\x18\x04 \x03(\x0b\x32/.polykey.v2.RotateKeyItem.GenerationParamsEntryR\x10generationParams\x12\x38\n\x18preserve_access_policies\x18\x05 \x01(\x08R\x16preserveAccessPolicies\x1a\x43\n\x15GenerationParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd6\x01\n\x16\x42\x61tchRotateKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12-\n\x04keys\x18\x02 \x03(\x0b\x32\x19.polykey.v2.RotateKeyItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"\x8b\x01\n\x15\x42\x61tchRotateKeysResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x39\n\x07success\x18\x02 \x01(\x0b\x32\x1d.polykey.v2.RotateKeyResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xef\x01\n\x17\x42\x61tchRotateKeysResponse\x12;\n\x07results\x18\x01 \x03(\x0b\x32!.polykey.v2.BatchRotateKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xe8\x01\n\rRevokeKeyItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12+\n\x11revocation_reason\x18\x02 \x01(\tR\x10revocationReason\x12\x1c\n\timmediate\x18\x03 \x01(\x08R\timmediate\x12=\n\x0c\x65\x66\x66\x65\x63tive_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x65\x66\x66\x65\x63tiveAt\x12\x36\n\x17notify_external_systems\x18\x05 \x01(\x08R\x15notifyExternalSystems\"\xd6\x01\n\x16\x42\x61tchRevokeKeysRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12-\n\x04keys\x18\x02 \x03(\x0b\x32\x19.polykey.v2.RevokeKeyItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"l\n\x15\x42\x61tchRevokeKeysResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xef\x01\n\x17\x42\x61tchRevokeKeysResponse\x12;\n\x07results\x18\x01 \x03(\x0b\x32!.polykey.v2.BatchRevokeKeysResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xba\x05\n\x15UpdateKeyMetadataItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12P\n\x0btags_to_add\x18\x03 \x03(\x0b\x32\x30.polykey.v2.UpdateKeyMetadataItem.TagsToAddEntryR\ttagsToAdd\x12$\n\x0etags_to_remove\x18\x04 \x03(\tR\x0ctagsToRemove\x12&\n\x0f\x63ontexts_to_add\x18\x05 \x03(\tR\rcontextsToAdd\x12,\n\x12\x63ontexts_to_remove\x18\x06 \x03(\tR\x10\x63ontextsToRemove\x12\x65\n\x12policies_to_update\x18\x07 \x03(\x0b\x32\x37.polykey.v2.UpdateKeyMetadataItem.PoliciesToUpdateEntryR\x10policiesToUpdate\x12>\n\nexpires_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\texpiresAt\x88\x01\x01\x12\x34\n\x13\x64\x61ta_classification\x18\t \x01(\tH\x02R\x12\x64\x61taClassification\x88\x01\x01\x1a<\n\x0eTagsToAddEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15PoliciesToUpdateEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_descriptionB\r\n\x0b_expires_atB\x16\n\x14_data_classification\"\xe5\x01\n\x1d\x42\x61tchUpdateKeyMetadataRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12\x35\n\x04keys\x18\x02 \x03(\x0b\x32!.polykey.v2.UpdateKeyMetadataItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x03 \x01(\x08R\x0f\x63ontinueOnError\x12\x16\n\x06\x61tomic\x18\x04 \x01(\x08R\x06\x61tomic\"s\n\x1c\x42\x61tchUpdateKeyMetadataResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x1a\n\x07success\x18\x02 \x01(\x08H\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xfd\x01\n\x1e\x42\x61tchUpdateKeyMetadataResponse\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32(.polykey.v2.BatchUpdateKeyMetadataResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCount\"\xb1\x01\n\x12GetKeyMetadataItem\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12\x34\n\x16include_access_history\x18\x02 \x01(\x08R\x14includeAccessHistory\x12\x34\n\x16include_policy_details\x18\x03 \x01(\x08R\x14includePolicyDetails\x12\x18\n\x07version\x18\x04 \x01(\x05R\x07version\"\x85\x02\n\x1a\x42\x61tchGetKeyMetadataRequest\x12I\n\x11requester_context\x18\x01 \x01(\x0b\x32\x1c.polykey.v2.RequesterContextR\x10requesterContext\x12<\n\nattributes\x18\x02 \x01(\x0b\x32\x1c.polykey.v2.AccessAttributesR\nattributes\x12\x32\n\x04keys\x18\x03 \x03(\x0b\x32\x1e.polykey.v2.GetKeyMetadataItemR\x04keys\x12*\n\x11\x63ontinue_on_error\x18\x04 \x01(\x08R\x0f\x63ontinueOnError\"\x94\x01\n\x19\x42\x61tchGetKeyMetadataResult\x12\x15\n\x06key_id\x18\x01 \x01(\tR\x05keyId\x12>\n\x07success\x18\x02 \x01(\x0b\x32\".polykey.v2.GetKeyMetadataResponseH\x00R\x07success\x12\x16\n\x05\x65rror\x18\x03 \x01(\tH\x00R\x05\x65rrorB\x08\n\x06result\"\xf7\x01\n\x1b\x42\x61tchGetKeyMetadataResponse\x12?\n\x07results\x18\x01 \x03(\x0b\x32%.polykey.v2.BatchGetKeyMetadataResultR\x07results\x12I\n\x12response_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11responseTimestamp\x12)\n\x10successful_count\x18\x03 \x01(\x05R\x0fsuccessfulCount\x12!\n\x0c\x66\x61iled_count\x18\x04 \x01(\x05R\x0b\x66\x61iledCountB\xb0\x01\n\x0e\x63om.polykey.v2B\x14\x42\x61tchOperationsProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.batch_operations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\024BatchOperationsProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_CREATEKEYITEM_TAGSENTRY']._loaded_options = None
  _globals['_CREATEKEYITEM_TAGSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._loaded_options = None
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._loaded_options = None
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._loaded_options = None
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._serialized_options = b'8\001'
  _globals['_KEYREQUESTITEM']._serialized_start=171
  _globals['_KEYREQUESTITEM']._serialized_end=273
  _globals['_BATCHGETKEYSREQUEST']._serialized_start=276
  _globals['_BATCHGETKEYSREQUEST']._serialized_end=526
  _globals['_BATCHGETKEYSRESULT']._serialized_start=529
  _globals['_BATCHGETKEYSRESULT']._serialized_end=662
  _globals['_BATCHGETKEYSRESPONSE']._serialized_start=665
  _globals['_BATCHGETKEYSRESPONSE']._serialized_end=898
  _globals['_CREATEKEYITEM']._serialized_start=901
  _globals['_CREATEKEYITEM']._serialized_end=1602
  _globals['_CREATEKEYITEM_TAGSENTRY']._serialized_start=1411
  _globals['_CREATEKEYITEM_TAGSENTRY']._serialized_end=1466
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._serialized_start=1468
  _globals['_CREATEKEYITEM_ACCESSPOLICIESENTRY']._serialized_end=1533
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_start=1535
  _globals['_CREATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_end=1602
  _globals['_BATCHCREATEKEYSREQUEST']._serialized_start=1605
  _globals['_BATCHCREATEKEYSREQUEST']._serialized_end=1819
  _globals['_BATCHCREATEKEYSRESULT']._serialized_start=1822
  _globals['_BATCHCREATEKEYSRESULT']._serialized_end=1975
  _globals['_BATCHCREATEKEYSRESPONSE']._serialized_start=1978
  _globals['_BATCHCREATEKEYSRESPONSE']._serialized_end=2217
  _globals['_ROTATEKEYITEM']._serialized_start=2220
  _globals['_ROTATEKEYITEM']._serialized_end=2587
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_start=1535
  _globals['_ROTATEKEYITEM_GENERATIONPARAMSENTRY']._serialized_end=1602
  _globals['_BATCHROTATEKEYSREQUEST']._serialized_start=2590
  _globals['_BATCHROTATEKEYSREQUEST']._serialized_end=2804
  _globals['_BATCHROTATEKEYSRESULT']._serialized_start=2807
  _globals['_BATCHROTATEKEYSRESULT']._serialized_end=2946
  _globals['_BATCHROTATEKEYSRESPONSE']._serialized_start=2949
  _globals['_BATCHROTATEKEYSRESPONSE']._serialized_end=3188
  _globals['_REVOKEKEYITEM']._serialized_start=3191
  _globals['_REVOKEKEYITEM']._serialized_end=3423
  _globals['_BATCHREVOKEKEYSREQUEST']._serialized_start=3426
  _globals['_BATCHREVOKEKEYSREQUEST']._serialized_end=3640
  _globals['_BATCHREVOKEKEYSRESULT']._serialized_start=3642
  _globals['_BATCHREVOKEKEYSRESULT']._serialized_end=3750
  _globals['_BATCHREVOKEKEYSRESPONSE']._serialized_start=3753
  _globals['_BATCHREVOKEKEYSRESPONSE']._serialized_end=3992
  _globals['_UPDATEKEYMETADATAITEM']._serialized_start=3995
  _globals['_UPDATEKEYMETADATAITEM']._serialized_end=4693
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._serialized_start=4509
  _globals['_UPDATEKEYMETADATAITEM_TAGSTOADDENTRY']._serialized_end=4569
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._serialized_start=4571
  _globals['_UPDATEKEYMETADATAITEM_POLICIESTOUPDATEENTRY']._serialized_end=4638
  _globals['_BATCHUPDATEKEYMETADATAREQUEST']._serialized_start=4696
  _globals['_BATCHUPDATEKEYMETADATAREQUEST']._serialized_end=4925
  _globals['_BATCHUPDATEKEYMETADATARESULT']._serialized_start=4927
  _globals['_BATCHUPDATEKEYMETADATARESULT']._serialized_end=5042
  _globals['_BATCHUPDATEKEYMETADATARESPONSE']._serialized_start=5045
  _globals['_BATCHUPDATEKEYMETADATARESPONSE']._serialized_end=5298
  _globals['_GETKEYMETADATAITEM']._serialized_start=5301
  _globals['_GETKEYMETADATAITEM']._serialized_end=5478
  _globals['_BATCHGETKEYMETADATAREQUEST']._serialized_start=5481
  _globals['_BATCHGETKEYMETADATAREQUEST']._serialized_end=5742
  _globals['_BATCHGETKEYMETADATARESULT']._serialized_start=5745
  _globals['_BATCHGETKEYMETADATARESULT']._serialized_end=5893
  _globals['_BATCHGETKEYMETADATARESPONSE']._serialized_start=5896
  _globals['_BATCHGETKEYMETADATARESPONSE']._serialized_end=6143
# @@protoc_insertion_point(module_scope)
