# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spounge.polykey.v2 import metrics_pb2 as polykey_dot_v2_dot_metrics__pb2
from spounge.polykey.v2 import auth_pb2 as polykey_dot_v2_dot_auth__pb2
from spounge.polykey.v2 import single_operations_pb2 as polykey_dot_v2_dot_single__operations__pb2
from spounge.polykey.v2 import batch_operations_pb2 as polykey_dot_v2_dot_batch__operations__pb2
from spounge.polykey.v2 import stream_operations_pb2 as polykey_dot_v2_dot_stream__operations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18polykey/v2/service.proto\x12\npolykey.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18polykey/v2/metrics.proto\x1a\x15polykey/v2/auth.proto\x1a\"polykey/v2/single_operations.proto\x1a!polykey/v2/batch_operations.proto\x1a\"polykey/v2/stream_operations.proto2\x81\x10\n\x0ePolykeyService\x12\x46\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x1f.polykey.v2.HealthCheckResponse\x12?\n\x06GetKey\x12\x19.polykey.v2.GetKeyRequest\x1a\x1a.polykey.v2.GetKeyResponse\x12\x45\n\x08ListKeys\x12\x1b.polykey.v2.ListKeysRequest\x1a\x1c.polykey.v2.ListKeysResponse\x12H\n\tCreateKey\x12\x1c.polykey.v2.CreateKeyRequest\x1a\x1d.polykey.v2.CreateKeyResponse\x12H\n\tRotateKey\x12\x1c.polykey.v2.RotateKeyRequest\x1a\x1d.polykey.v2.RotateKeyResponse\x12\x41\n\tRevokeKey\x12\x1c.polykey.v2.RevokeKeyRequest\x1a\x16.google.protobuf.Empty\x12Q\n\x11UpdateKeyMetadata\x12$.polykey.v2.UpdateKeyMetadataRequest\x1a\x16.google.protobuf.Empty\x12W\n\x0eGetKeyMetadata\x12!.polykey.v2.GetKeyMetadataRequest\x1a\".polykey.v2.GetKeyMetadataResponse\x12Q\n\x0c\x42\x61tchGetKeys\x12\x1f.polykey.v2.BatchGetKeysRequest\x1a .polykey.v2.BatchGetKeysResponse\x12Z\n\x0f\x42\x61tchCreateKeys\x12\".polykey.v2.BatchCreateKeysRequest\x1a#.polykey.v2.BatchCreateKeysResponse\x12Z\n\x0f\x42\x61tchRotateKeys\x12\".polykey.v2.BatchRotateKeysRequest\x1a#.polykey.v2.BatchRotateKeysResponse\x12Z\n\x0f\x42\x61tchRevokeKeys\x12\".polykey.v2.BatchRevokeKeysRequest\x1a#.polykey.v2.BatchRevokeKeysResponse\x12o\n\x16\x42\x61tchUpdateKeyMetadata\x12).polykey.v2.BatchUpdateKeyMetadataRequest\x1a*.polykey.v2.BatchUpdateKeyMetadataResponse\x12\x66\n\x13\x42\x61tchGetKeyMetadata\x12&.polykey.v2.BatchGetKeyMetadataRequest\x1a\'.polykey.v2.BatchGetKeyMetadataResponse\x12V\n\rStreamGetKeys\x12 .polykey.v2.StreamGetKeysRequest\x1a!.polykey.v2.StreamGetKeysResponse0\x01\x12\x61\n\x10StreamCreateKeys\x12#.polykey.v2.StreamCreateKeysRequest\x1a$.polykey.v2.StreamCreateKeysResponse(\x01\x30\x01\x12\x61\n\x10StreamRotateKeys\x12#.polykey.v2.StreamRotateKeysRequest\x1a$.polykey.v2.StreamRotateKeysResponse(\x01\x30\x01\x12\x61\n\x10StreamRevokeKeys\x12#.polykey.v2.StreamRevokeKeysRequest\x1a$.polykey.v2.StreamRevokeKeysResponse(\x01\x30\x01\x12v\n\x17StreamUpdateKeyMetadata\x12*.polykey.v2.StreamUpdateKeyMetadataRequest\x1a+.polykey.v2.StreamUpdateKeyMetadataResponse(\x01\x30\x01\x12m\n\x14StreamGetKeyMetadata\x12\'.polykey.v2.StreamGetKeyMetadataRequest\x1a(.polykey.v2.StreamGetKeyMetadataResponse(\x01\x30\x01\x12Q\n\x0c\x41uthenticate\x12\x1f.polykey.v2.AuthenticateRequest\x1a .polykey.v2.AuthenticateResponse\x12Q\n\x0cRefreshToken\x12\x1f.polykey.v2.RefreshTokenRequest\x1a .polykey.v2.RefreshTokenResponse\x12N\n\x0bRevokeToken\x12\x1e.polykey.v2.RevokeTokenRequest\x1a\x1f.polykey.v2.RevokeTokenResponseB\xa8\x01\n\x0e\x63om.polykey.v2B\x0cServiceProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\014ServiceProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_POLYKEYSERVICE']._serialized_start=226
  _globals['_POLYKEYSERVICE']._serialized_end=2275
# @@protoc_insertion_point(module_scope)
