# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from user.v2 import user_service_pb2 as user_dot_v2_dot_user__service__pb2


class UserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserProfile = channel.unary_unary(
            "/user.v2.UserService/GetUserProfile",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.FromString,
            _registered_method=True,
        )
        self.UpdateUserProfile = channel.unary_unary(
            "/user.v2.UserService/UpdateUserProfile",
            request_serializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
            _registered_method=True,
        )
        self.AddManagedSecret = channel.unary_unary(
            "/user.v2.UserService/AddManagedSecret",
            request_serializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.FromString,
            _registered_method=True,
        )
        self.ListManagedSecrets = channel.unary_unary(
            "/user.v2.UserService/ListManagedSecrets",
            request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.FromString,
            _registered_method=True,
        )
        self.GetManagedSecret = channel.unary_unary(
            "/user.v2.UserService/GetManagedSecret",
            request_serializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.FromString,
            _registered_method=True,
        )
        self.DeleteManagedSecret = channel.unary_unary(
            "/user.v2.UserService/DeleteManagedSecret",
            request_serializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.SerializeToString,
            response_deserializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.FromString,
            _registered_method=True,
        )


class UserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateUserProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListManagedSecrets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteManagedSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserProfile,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.SerializeToString,
        ),
        "UpdateUserProfile": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateUserProfile,
            request_deserializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.SerializeToString,
        ),
        "AddManagedSecret": grpc.unary_unary_rpc_method_handler(
            servicer.AddManagedSecret,
            request_deserializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.SerializeToString,
        ),
        "ListManagedSecrets": grpc.unary_unary_rpc_method_handler(
            servicer.ListManagedSecrets,
            request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.SerializeToString,
        ),
        "GetManagedSecret": grpc.unary_unary_rpc_method_handler(
            servicer.GetManagedSecret,
            request_deserializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.SerializeToString,
        ),
        "DeleteManagedSecret": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteManagedSecret,
            request_deserializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.FromString,
            response_serializer=user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "user.v2.UserService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers("user.v2.UserService", rpc_method_handlers)


# This class is part of an EXPERIMENTAL API.
class UserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/GetUserProfile",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            user_dot_v2_dot_user__service__pb2.GetUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def UpdateUserProfile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/UpdateUserProfile",
            user_dot_v2_dot_user__service__pb2.UpdateUserProfileRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.UpdateUserProfileResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def AddManagedSecret(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/AddManagedSecret",
            user_dot_v2_dot_user__service__pb2.AddManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.AddManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def ListManagedSecrets(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/ListManagedSecrets",
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            user_dot_v2_dot_user__service__pb2.ListManagedSecretsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def GetManagedSecret(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/GetManagedSecret",
            user_dot_v2_dot_user__service__pb2.GetManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.GetManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def DeleteManagedSecret(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/user.v2.UserService/DeleteManagedSecret",
            user_dot_v2_dot_user__service__pb2.DeleteManagedSecretRequest.SerializeToString,
            user_dot_v2_dot_user__service__pb2.DeleteManagedSecretResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
