# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: llm/v2/llm.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "llm/v2/llm.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10llm/v2/llm.proto\x12\x06llm.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto"n\n\x07Message\x12\'\n\x04role\x18\x01 \x01(\x0e\x32\x13.llm.v2.MessageRoleR\x04role\x12\x18\n\x07\x63ontent\x18\x02 \x01(\tR\x07\x63ontent\x12\x17\n\x04name\x18\x03 \x01(\tH\x00R\x04name\x88\x01\x01\x42\x07\n\x05_name"u\n\x04Tool\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x37\n\nparameters\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters"L\n\x08ToolCall\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1c\n\targuments\x18\x03 \x01(\tR\targuments"\xef\x01\n\x10GenerationParams\x12%\n\x0btemperature\x18\x01 \x01(\x02H\x00R\x0btemperature\x88\x01\x01\x12\x18\n\x05top_p\x18\x02 \x01(\x02H\x01R\x04topP\x88\x01\x01\x12"\n\nmax_tokens\x18\x03 \x01(\x05H\x02R\tmaxTokens\x88\x01\x01\x12%\n\x0estop_sequences\x18\x04 \x03(\tR\rstopSequences\x12\x1b\n\x06stream\x18\x05 \x01(\x08H\x03R\x06stream\x88\x01\x01\x42\x0e\n\x0c_temperatureB\x08\n\x06_top_pB\r\n\x0b_max_tokensB\t\n\x07_stream"\x81\x01\n\nTokenUsage\x12#\n\rprompt_tokens\x18\x01 \x01(\x05R\x0cpromptTokens\x12+\n\x11\x63ompletion_tokens\x18\x02 \x01(\x05R\x10\x63ompletionTokens\x12!\n\x0ctotal_tokens\x18\x03 \x01(\x05R\x0btotalTokens"\x9d\x02\n\x13GenerateTextRequest\x12,\n\x08provider\x18\x01 \x01(\x0e\x32\x10.llm.v2.ProviderR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12+\n\x08messages\x18\x03 \x03(\x0b\x32\x0f.llm.v2.MessageR\x08messages\x12\x35\n\x06params\x18\x04 \x01(\x0b\x32\x18.llm.v2.GenerationParamsH\x00R\x06params\x88\x01\x01\x12"\n\x05tools\x18\x05 \x03(\x0b\x32\x0c.llm.v2.ToolR\x05tools\x12/\n\x08metadata\x18\x06 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadataB\t\n\x07_params"\x8c\x02\n\x14GenerateTextResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12:\n\x10response_message\x18\x02 \x01(\x0b\x32\x0f.llm.v2.MessageR\x0fresponseMessage\x12/\n\ntool_calls\x18\x03 \x03(\x0b\x32\x10.llm.v2.ToolCallR\ttoolCalls\x12-\n\x05usage\x18\x04 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x12#\n\rfinish_reason\x18\x05 \x01(\tR\x0c\x66inishReasonB\x08\n\x06_usage"R\n\x19GenerateTextStreamRequest\x12\x35\n\x07request\x18\x01 \x01(\x0b\x32\x1b.llm.v2.GenerateTextRequestR\x07request"\xed\x01\n\x1aGenerateTextStreamResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x14\n\x05\x64\x65lta\x18\x02 \x01(\tR\x05\x64\x65lta\x12-\n\x05usage\x18\x03 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x12(\n\rfinish_reason\x18\x04 \x01(\tH\x01R\x0c\x66inishReason\x88\x01\x01\x12\x19\n\x08is_final\x18\x05 \x01(\x08R\x07isFinalB\x08\n\x06_usageB\x10\n\x0e_finish_reason"\xa5\x01\n\x18GenerateEmbeddingRequest\x12,\n\x08provider\x18\x01 \x01(\x0e\x32\x10.llm.v2.ProviderR\x08provider\x12\x14\n\x05model\x18\x02 \x01(\tR\x05model\x12\x14\n\x05texts\x18\x03 \x03(\tR\x05texts\x12/\n\x08metadata\x18\x04 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadata"A\n\tEmbedding\x12\x16\n\x06values\x18\x01 \x03(\x02R\x06values\x12\x1c\n\tdimension\x18\x02 \x01(\x05R\tdimension"\xb2\x01\n\x19GenerateEmbeddingResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12\x31\n\nembeddings\x18\x02 \x03(\x0b\x32\x11.llm.v2.EmbeddingR\nembeddings\x12-\n\x05usage\x18\x03 \x01(\x0b\x32\x12.llm.v2.TokenUsageH\x00R\x05usage\x88\x01\x01\x42\x08\n\x06_usage*\xab\x01\n\x08Provider\x12\x18\n\x14PROVIDER_UNSPECIFIED\x10\x00\x12\x13\n\x0fPROVIDER_OPENAI\x10\x01\x12\x16\n\x12PROVIDER_ANTHROPIC\x10\x02\x12\x13\n\x0fPROVIDER_GOOGLE\x10\x03\x12\x19\n\x15PROVIDER_AZURE_OPENAI\x10\x04\x12\x13\n\x0fPROVIDER_COHERE\x10\x05\x12\x13\n\x0fPROVIDER_OLLAMA\x10\x06*\x8e\x01\n\x0bMessageRole\x12\x1c\n\x18MESSAGE_ROLE_UNSPECIFIED\x10\x00\x12\x17\n\x13MESSAGE_ROLE_SYSTEM\x10\x01\x12\x15\n\x11MESSAGE_ROLE_USER\x10\x02\x12\x1a\n\x16MESSAGE_ROLE_ASSISTANT\x10\x03\x12\x15\n\x11MESSAGE_ROLE_TOOL\x10\x04\x32\x9e\x02\n\x12LLMProviderService\x12K\n\x0cGenerateText\x12\x1b.llm.v2.GenerateTextRequest\x1a\x1c.llm.v2.GenerateTextResponse"\x00\x12_\n\x12GenerateTextStream\x12!.llm.v2.GenerateTextStreamRequest\x1a".llm.v2.GenerateTextStreamResponse"\x00\x30\x01\x12Z\n\x11GenerateEmbedding\x12 .llm.v2.GenerateEmbeddingRequest\x1a!.llm.v2.GenerateEmbeddingResponse"\x00\x42\x89\x01\n\ncom.llm.v2B\x08LlmProtoP\x01Z8github.com/spounge-ai/spounge-protos/gen/go/llm/v2;llmv2\xa2\x02\x03LXX\xaa\x02\x06Llm.V2\xca\x02\x06Llm\\V2\xe2\x02\x12Llm\\V2\\GPBMetadata\xea\x02\x07Llm::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "llm.v2.llm_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\ncom.llm.v2B\010LlmProtoP\001Z8github.com/spounge-ai/spounge-protos/gen/go/llm/v2;llmv2\242\002\003LXX\252\002\006Llm.V2\312\002\006Llm\\V2\342\002\022Llm\\V2\\GPBMetadata\352\002\007Llm::V2"
    _globals["_PROVIDER"]._serialized_start = 2065
    _globals["_PROVIDER"]._serialized_end = 2236
    _globals["_MESSAGEROLE"]._serialized_start = 2239
    _globals["_MESSAGEROLE"]._serialized_end = 2381
    _globals["_MESSAGE"]._serialized_start = 82
    _globals["_MESSAGE"]._serialized_end = 192
    _globals["_TOOL"]._serialized_start = 194
    _globals["_TOOL"]._serialized_end = 311
    _globals["_TOOLCALL"]._serialized_start = 313
    _globals["_TOOLCALL"]._serialized_end = 389
    _globals["_GENERATIONPARAMS"]._serialized_start = 392
    _globals["_GENERATIONPARAMS"]._serialized_end = 631
    _globals["_TOKENUSAGE"]._serialized_start = 634
    _globals["_TOKENUSAGE"]._serialized_end = 763
    _globals["_GENERATETEXTREQUEST"]._serialized_start = 766
    _globals["_GENERATETEXTREQUEST"]._serialized_end = 1051
    _globals["_GENERATETEXTRESPONSE"]._serialized_start = 1054
    _globals["_GENERATETEXTRESPONSE"]._serialized_end = 1322
    _globals["_GENERATETEXTSTREAMREQUEST"]._serialized_start = 1324
    _globals["_GENERATETEXTSTREAMREQUEST"]._serialized_end = 1406
    _globals["_GENERATETEXTSTREAMRESPONSE"]._serialized_start = 1409
    _globals["_GENERATETEXTSTREAMRESPONSE"]._serialized_end = 1646
    _globals["_GENERATEEMBEDDINGREQUEST"]._serialized_start = 1649
    _globals["_GENERATEEMBEDDINGREQUEST"]._serialized_end = 1814
    _globals["_EMBEDDING"]._serialized_start = 1816
    _globals["_EMBEDDING"]._serialized_end = 1881
    _globals["_GENERATEEMBEDDINGRESPONSE"]._serialized_start = 1884
    _globals["_GENERATEEMBEDDINGRESPONSE"]._serialized_end = 2062
    _globals["_LLMPROVIDERSERVICE"]._serialized_start = 2384
    _globals["_LLMPROVIDERSERVICE"]._serialized_end = 2670
# @@protoc_insertion_point(module_scope)
