# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'polykey/v2/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from spounge.common.v2 import common_pb2 as common_dot_v2_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15polykey/v2/auth.proto\x12\npolykey.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x16\x63ommon/v2/common.proto\"j\n\x13\x41uthenticateRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x17\n\x07\x61pi_key\x18\x02 \x01(\tR\x06\x61piKey\x12\x1d\n\ngrant_type\x18\x03 \x01(\tR\tgrantType\"\x8a\x02\n\x14\x41uthenticateResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1d\n\ntoken_type\x18\x02 \x01(\tR\ttokenType\x12\x1d\n\nexpires_in\x18\x03 \x01(\x03R\texpiresIn\x12 \n\x0bpermissions\x18\x04 \x03(\tR\x0bpermissions\x12\x37\n\tissued_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08issuedAt\x12\x36\n\x0b\x63lient_tier\x18\x06 \x01(\x0e\x32\x15.common.v2.ClientTierR\nclientTier\":\n\x13RefreshTokenRequest\x12#\n\rrefresh_token\x18\x01 \x01(\tR\x0crefreshToken\"\xb0\x01\n\x14RefreshTokenResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1d\n\ntoken_type\x18\x02 \x01(\tR\ttokenType\x12\x1d\n\nexpires_in\x18\x03 \x01(\x03R\texpiresIn\x12\x37\n\tissued_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08issuedAt\"T\n\x12RevokeTokenRequest\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\"j\n\x13RevokeTokenResponse\x12\x18\n\x07revoked\x18\x01 \x01(\x08R\x07revoked\x12\x39\n\nrevoked_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\trevokedAt\"\xbf\x02\n\nClientInfo\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x1f\n\x0b\x63lient_name\x18\x02 \x01(\tR\nclientName\x12 \n\x0bpermissions\x18\x03 \x03(\tR\x0bpermissions\x12 \n\x0b\x65nvironment\x18\x04 \x01(\tR\x0b\x65nvironment\x12\x39\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12<\n\x0clast_used_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUsedAt\x12\x36\n\x0b\x63lient_tier\x18\x07 \x01(\x0e\x32\x15.common.v2.ClientTierR\nclientTierB\xa5\x01\n\x0e\x63om.polykey.v2B\tAuthProtoP\x01Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'polykey.v2.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.polykey.v2B\tAuthProtoP\001Z?github.com/spounge-ai/spounge-proto/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2'
  _globals['_AUTHENTICATEREQUEST']._serialized_start=94
  _globals['_AUTHENTICATEREQUEST']._serialized_end=200
  _globals['_AUTHENTICATERESPONSE']._serialized_start=203
  _globals['_AUTHENTICATERESPONSE']._serialized_end=469
  _globals['_REFRESHTOKENREQUEST']._serialized_start=471
  _globals['_REFRESHTOKENREQUEST']._serialized_end=529
  _globals['_REFRESHTOKENRESPONSE']._serialized_start=532
  _globals['_REFRESHTOKENRESPONSE']._serialized_end=708
  _globals['_REVOKETOKENREQUEST']._serialized_start=710
  _globals['_REVOKETOKENREQUEST']._serialized_end=794
  _globals['_REVOKETOKENRESPONSE']._serialized_start=796
  _globals['_REVOKETOKENRESPONSE']._serialized_end=902
  _globals['_CLIENTINFO']._serialized_start=905
  _globals['_CLIENTINFO']._serialized_end=1224
# @@protoc_insertion_point(module_scope)
