# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: polykey/v2/polykey_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "polykey/v2/polykey_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n polykey/v2/polykey_service.proto\x12\npolykey.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1cgoogle/protobuf/struct.proto"\xcb\x01\n\x12\x45xecuteToolRequest\x12\x1b\n\ttool_name\x18\x01 \x01(\tR\x08toolName\x12\x37\n\nparameters\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\nparameters\x12 \n\tsecret_id\x18\x03 \x01(\tH\x00R\x08secretId\x88\x01\x01\x12/\n\x08metadata\x18\x04 \x01(\x0b\x32\x13.common.v2.MetadataR\x08metadataB\x0c\n\n_secret_id"\xe5\x01\n\x13\x45xecuteToolResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status\x12%\n\rstring_output\x18\x02 \x01(\tH\x00R\x0cstringOutput\x12>\n\rstruct_output\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0cstructOutput\x12\x32\n\x0b\x66ile_output\x18\x04 \x01(\x0b\x32\x0f.common.v2.FileH\x00R\nfileOutputB\x08\n\x06output2`\n\x0ePolykeyService\x12N\n\x0b\x45xecuteTool\x12\x1e.polykey.v2.ExecuteToolRequest\x1a\x1f.polykey.v2.ExecuteToolResponseB\xb0\x01\n\x0e\x63om.polykey.v2B\x13PolykeyServiceProtoP\x01Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\xa2\x02\x03PXX\xaa\x02\nPolykey.V2\xca\x02\nPolykey\\V2\xe2\x02\x16Polykey\\V2\\GPBMetadata\xea\x02\x0bPolykey::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "polykey.v2.polykey_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\016com.polykey.v2B\023PolykeyServiceProtoP\001Z@github.com/spounge-ai/spounge-protos/gen/go/polykey/v2;polykeyv2\242\002\003PXX\252\002\nPolykey.V2\312\002\nPolykey\\V2\342\002\026Polykey\\V2\\GPBMetadata\352\002\013Polykey::V2"
    _globals["_EXECUTETOOLREQUEST"]._serialized_start = 103
    _globals["_EXECUTETOOLREQUEST"]._serialized_end = 306
    _globals["_EXECUTETOOLRESPONSE"]._serialized_start = 309
    _globals["_EXECUTETOOLRESPONSE"]._serialized_end = 538
    _globals["_POLYKEYSERVICE"]._serialized_start = 540
    _globals["_POLYKEYSERVICE"]._serialized_end = 636
# @@protoc_insertion_point(module_scope)
