# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user/v2/user_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "user/v2/user_service.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1auser/v2/user_service.proto\x12\x07user.v2\x1a\x16\x63ommon/v2/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1biam/v2/managed_secret.proto\x1a\x12user/v2/user.proto"H\n\x16GetUserProfileResponse\x12.\n\x07profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile"\x87\x01\n\x18UpdateUserProfileRequest\x12;\n\x0bupdate_mask\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask\x12.\n\x07profile\x18\x02 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile"K\n\x19UpdateUserProfileResponse\x12.\n\x07profile\x18\x01 \x01(\x0b\x32\x14.user.v2.UserProfileR\x07profile"\x88\x01\n\x17\x41\x64\x64ManagedSecretRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x19.iam.v2.ManagedSecretTypeR\x04type\x12*\n\x11plain_text_secret\x18\x03 \x01(\tR\x0fplainTextSecret"I\n\x18\x41\x64\x64ManagedSecretResponse\x12-\n\x06secret\x18\x01 \x01(\x0b\x32\x15.iam.v2.ManagedSecretR\x06secret"M\n\x1aListManagedSecretsResponse\x12/\n\x07secrets\x18\x01 \x03(\x0b\x32\x15.iam.v2.ManagedSecretR\x07secrets"6\n\x17GetManagedSecretRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId"I\n\x18GetManagedSecretResponse\x12-\n\x06secret\x18\x01 \x01(\x0b\x32\x15.iam.v2.ManagedSecretR\x06secret"9\n\x1a\x44\x65leteManagedSecretRequest\x12\x1b\n\tsecret_id\x18\x01 \x01(\tR\x08secretId"H\n\x1b\x44\x65leteManagedSecretResponse\x12)\n\x06status\x18\x01 \x01(\x0b\x32\x11.common.v2.StatusR\x06status2\xa7\x04\n\x0bUserService\x12K\n\x0eGetUserProfile\x12\x16.google.protobuf.Empty\x1a\x1f.user.v2.GetUserProfileResponse"\x00\x12\\\n\x11UpdateUserProfile\x12!.user.v2.UpdateUserProfileRequest\x1a".user.v2.UpdateUserProfileResponse"\x00\x12Y\n\x10\x41\x64\x64ManagedSecret\x12 .user.v2.AddManagedSecretRequest\x1a!.user.v2.AddManagedSecretResponse"\x00\x12S\n\x12ListManagedSecrets\x12\x16.google.protobuf.Empty\x1a#.user.v2.ListManagedSecretsResponse"\x00\x12Y\n\x10GetManagedSecret\x12 .user.v2.GetManagedSecretRequest\x1a!.user.v2.GetManagedSecretResponse"\x00\x12\x62\n\x13\x44\x65leteManagedSecret\x12#.user.v2.DeleteManagedSecretRequest\x1a$.user.v2.DeleteManagedSecretResponse"\x00\x42\x98\x01\n\x0b\x63om.user.v2B\x10UserServiceProtoP\x01Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\xa2\x02\x03UXX\xaa\x02\x07User.V2\xca\x02\x07User\\V2\xe2\x02\x13User\\V2\\GPBMetadata\xea\x02\x08User::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "user.v2.user_service_pb2", _globals
)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\013com.user.v2B\020UserServiceProtoP\001Z:github.com/spounge-ai/spounge-protos/gen/go/user/v2;userv2\242\002\003UXX\252\002\007User.V2\312\002\007User\\V2\342\002\023User\\V2\\GPBMetadata\352\002\010User::V2"
    _globals["_GETUSERPROFILERESPONSE"]._serialized_start = 175
    _globals["_GETUSERPROFILERESPONSE"]._serialized_end = 247
    _globals["_UPDATEUSERPROFILEREQUEST"]._serialized_start = 250
    _globals["_UPDATEUSERPROFILEREQUEST"]._serialized_end = 385
    _globals["_UPDATEUSERPROFILERESPONSE"]._serialized_start = 387
    _globals["_UPDATEUSERPROFILERESPONSE"]._serialized_end = 462
    _globals["_ADDMANAGEDSECRETREQUEST"]._serialized_start = 465
    _globals["_ADDMANAGEDSECRETREQUEST"]._serialized_end = 601
    _globals["_ADDMANAGEDSECRETRESPONSE"]._serialized_start = 603
    _globals["_ADDMANAGEDSECRETRESPONSE"]._serialized_end = 676
    _globals["_LISTMANAGEDSECRETSRESPONSE"]._serialized_start = 678
    _globals["_LISTMANAGEDSECRETSRESPONSE"]._serialized_end = 755
    _globals["_GETMANAGEDSECRETREQUEST"]._serialized_start = 757
    _globals["_GETMANAGEDSECRETREQUEST"]._serialized_end = 811
    _globals["_GETMANAGEDSECRETRESPONSE"]._serialized_start = 813
    _globals["_GETMANAGEDSECRETRESPONSE"]._serialized_end = 886
    _globals["_DELETEMANAGEDSECRETREQUEST"]._serialized_start = 888
    _globals["_DELETEMANAGEDSECRETREQUEST"]._serialized_end = 945
    _globals["_DELETEMANAGEDSECRETRESPONSE"]._serialized_start = 947
    _globals["_DELETEMANAGEDSECRETRESPONSE"]._serialized_end = 1019
    _globals["_USERSERVICE"]._serialized_start = 1022
    _globals["_USERSERVICE"]._serialized_end = 1573
# @@protoc_insertion_point(module_scope)
