# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: common/v2/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 6, 31, 1, "", "common/v2/common.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16\x63ommon/v2/common.proto\x12\tcommon.v2\x1a\x1cgoogle/protobuf/struct.proto"i\n\x06Status\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x31\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructR\x07\x64\x65tails"Z\n\x04\x46ile\x12\x1b\n\tfile_name\x18\x01 \x01(\tR\x08\x66ileName\x12\x1b\n\tmime_type\x18\x02 \x01(\tR\x08mimeType\x12\x18\n\x07\x63ontent\x18\x03 \x01(\x0cR\x07\x63ontent"C\n\x10PaginationParams\x12\x12\n\x04page\x18\x01 \x01(\x05R\x04page\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize"\x85\x01\n\x10PaginationResult\x12\x12\n\x04page\x18\x01 \x01(\x05R\x04page\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1f\n\x0btotal_items\x18\x03 \x01(\x05R\ntotalItems\x12\x1f\n\x0btotal_pages\x18\x04 \x01(\x05R\ntotalPages"\x1a\n\x08\x45ntityId\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id"~\n\x08Metadata\x12\x37\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x1f.common.v2.Metadata.FieldsEntryR\x06\x66ields\x1a\x39\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xa1\x01\n\rcom.common.v2B\x0b\x43ommonProtoP\x01Z>github.com/spounge-ai/spounge-protos/gen/go/common/v2;commonv2\xa2\x02\x03\x43XX\xaa\x02\tCommon.V2\xca\x02\tCommon\\V2\xe2\x02\x15\x43ommon\\V2\\GPBMetadata\xea\x02\nCommon::V2b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "common.v2.common_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals["DESCRIPTOR"]._loaded_options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\rcom.common.v2B\013CommonProtoP\001Z>github.com/spounge-ai/spounge-protos/gen/go/common/v2;commonv2\242\002\003CXX\252\002\tCommon.V2\312\002\tCommon\\V2\342\002\025Common\\V2\\GPBMetadata\352\002\nCommon::V2"
    _globals["_METADATA_FIELDSENTRY"]._loaded_options = None
    _globals["_METADATA_FIELDSENTRY"]._serialized_options = b"8\001"
    _globals["_STATUS"]._serialized_start = 67
    _globals["_STATUS"]._serialized_end = 172
    _globals["_FILE"]._serialized_start = 174
    _globals["_FILE"]._serialized_end = 264
    _globals["_PAGINATIONPARAMS"]._serialized_start = 266
    _globals["_PAGINATIONPARAMS"]._serialized_end = 333
    _globals["_PAGINATIONRESULT"]._serialized_start = 336
    _globals["_PAGINATIONRESULT"]._serialized_end = 469
    _globals["_ENTITYID"]._serialized_start = 471
    _globals["_ENTITYID"]._serialized_end = 497
    _globals["_METADATA"]._serialized_start = 499
    _globals["_METADATA"]._serialized_end = 625
    _globals["_METADATA_FIELDSENTRY"]._serialized_start = 568
    _globals["_METADATA_FIELDSENTRY"]._serialized_end = 625
# @@protoc_insertion_point(module_scope)
